@@ -15,21 +15,20 @@
 import abc
 
 from neutron.agent import rpc as agent_rpc
-from neutron.common import rpc as n_rpc
 from neutron import manager
 from neutron_lib.agent import l2_extension
 from neutron_lib.agent import topics
+from neutron_lib import rpc as n_rpc
 from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging
-import six
 
 from networking_sfc.services.sfc.drivers.ovs import rpc_topics as sfc_topics
 
 LOG = logging.getLogger(__name__)
 
 
-class SfcPluginApi(object):
+class SfcPluginApi():
     def __init__(self, topic, host):
         self.host = host
         self.target = oslo_messaging.Target(topic=topic, version='1.0')
@@ -48,8 +47,7 @@ class SfcPluginApi(object):
             host=self.host, port_id=port_id)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class SfcAgentDriver(object):
+class SfcAgentDriver(metaclass=abc.ABCMeta):
     """Defines stable abstract interface for SFC Agent Driver."""
 
     @abc.abstractmethod
@@ -88,9 +86,9 @@ class SfcAgentExtension(l2_extension.L2AgentExtension):
         """
         self.agent_api = agent_api
 
-    def handle_port(self, context, port):
+    def handle_port(self, context, data):
         """Handle agent SFC extension port add/update."""
-        port_id = port['port_id']
+        port_id = data['port_id']
         resync = False
         flowrule_status = []
         try:
@@ -115,13 +113,13 @@ class SfcAgentExtension(l2_extension.L2AgentExtension):
 
         return resync
 
-    def delete_port(self, context, port):
+    def delete_port(self, context, data):
         """Handle agent SFC extension port delete."""
-        port_id = port['port_id']
+        port_id = data['port_id']
         resync = False
         LOG.info("a device %s is removed", port_id)
         try:
-            self._delete_ports_flowrules_by_id(context, port_id)
+            self._delete_port_flowrules_by_id(context, port_id)
         except Exception as e:
             LOG.exception(e)
             LOG.error(
@@ -183,23 +181,23 @@ class SfcAgentExtension(l2_extension.L2AgentExtension):
             self.topic,
             consumers)
 
-    def _delete_ports_flowrules_by_id(self, context, ports_id):
+    def _delete_port_flowrules_by_id(self, context, port_id):
         flowrule_status = []
+        if not port_id:
+            return
         try:
-            LOG.debug("delete_port_id_flows received, ports_id= %s", ports_id)
-            count = 0
-            if ports_id:
-                for port_id in ports_id:
-                    flowrule = (
-                        self.sfc_plugin_rpc.get_flowrules_by_host_portid(
-                            context, port_id
-                        )
-                    )
-                    if flowrule:
-                        self.sfc.driver.delete_flow_rule(
-                            flowrule, flowrule_status)
-            LOG.debug(
-                "_delete_ports_flowrules_by_id received, count= %s", count)
+            LOG.debug("delete_port_flowrules_by_id for port_id= %s",
+                      port_id)
+            flowrule = (
+                self.sfc_plugin_rpc.get_flowrules_by_host_portid(
+                    context, port_id
+                )
+            )
+            if flowrule:
+                self.sfc.driver.delete_flow_rule(
+                    flowrule, flowrule_status)
+            LOG.debug("_delete_port_flowrules_by_id for port_id= %s finished",
+                      port_id)
         except Exception as e:
             LOG.exception(e)
             LOG.error("delete_port_id_flows failed")
